Learn R Programming

jollofR (version 0.6.5)

jollofR-package: jollofR: Small Area Population Estimation by Demographics

Description

Automatic disaggregation of small-area population estimates by demographic groups (e.g., age, sex, race, marital status, educational level, etc) along with the estimates of uncertainty, using advanced Bayesian statistical modelling approaches based on integrated nested Laplace approximation (INLA) Rue et al. (2009) tools:::Rd_expr_doi("10.1111/j.1467-9868.2008.00700.x") and stochastic partial differential equation (SPDE) methods Lindgren et al. (2011) tools:::Rd_expr_doi("10.1111/j.1467-9868.2011.00777.x"). The package implements hierarchical Bayesian modeling frameworks for small area estimation as described in Leasure et al. (2020) tools:::Rd_expr_doi("10.1073/pnas.1913050117") and Nnanatu et al. (2025) tools:::Rd_expr_doi("10.1038/s41467-025-59862-4").

Arguments

Author

Maintainer: Chibuzor Christopher Nnanatu cc.nnanatu@soton.ac.uk (ORCID)

Authors:

See Also